@@ -61,7 +61,7 @@ test_that("load_layer works with different datadir options", {
     normalizePath(paste0(p,"/"), winslash = "/", mustWork = TRUE)
   }
   rpath <- function(rs) {
-    path <- gsub("/vsizip/", "", dirname(raster(rs,1)@file@name), fixed = TRUE)
+    path <- gsub("/vsizip/", "", dirname(raster::raster(rs,1)@file@name), fixed = TRUE)
     normalize(path)
   }
   skip_on_cran()
@@ -178,61 +178,4 @@ test_that("GDAL virtual file system works to read zipped raster files", {
 })
 
 
-# # This test might be implemented or updated later
-#
-# test_that("Urls in the server are the same than in the package", {
-#   # Function to find the files available at the server
-#   # If this works: no need to update sdmpredictors with each version
-#   # Or at least it will be scalable to any server having data
-#   list_layers_new <- function(urldata){
-#     # Read server html and extract href as text
-#     node <- xml2::read_html(urldata)
-#     node <- xml2::xml_find_all(node, "//a")[-1]
-#     node <- xml2::xml_text(node)
-#     
-#     # Choose only tif files
-#     node <- node[grepl(".tif", node, fixed = TRUE)]
-#     
-#     # Add absolute url
-#     node <- gsub(" ", "./", node , fixed = TRUE)
-#     node <- xml2::url_absolute(node, urldata)
-#     
-#     # END
-#     return(node)
-#   }
-#   
-#   sdmpredictors <- list_layers_new("https://www.lifewatch.be/sdmpredictors/")
-#   biooraclev2 <- list_layers_new("https://bio-oracle.org/data/2.0/")
-#   biooraclev21 <- list_layers_new("https://bio-oracle.org/data/2.1/")
-#   
-#   server <- sort(unique(c(sdmpredictors, biooraclev2, biooraclev21)))
-#   
-#   sysdata <- sdmpredictors:::get_sysdata()
-#   package <- sort(unique(c(sysdata$layerlist$layer_url, sysdata$layerlistfuture$layer_url, sysdata$layerlistpaleo$layer_url)))
-#   
-#   expect_equal(server, package)
-#   
-# })
-
-
-# # This test depends on RCurl to work, this is not always the case
-# 
-# test_that("All layer urls exist", {
-#   check_skip()
-#   df_url <- data.frame(
-#     url = c(list_layers()$layer_url, list_layers_future()$layer_url, list_layers_paleo()$layer_url),
-#     exists = NA
-#   )
-#   for (url_i in 1:nrow(df_url)){
-#       df_url$exists <- RCurl::url.exists(url_i, useragent="https://github.com/lifewatch/sdmpredictors")
-#       Sys.sleep(0.1)
-#   }
-#   expect_true(all(df_url$exists))
-#   if(!all(df_url$exists)){
-#     fail <- paste0(tempfile(), ".csv")
-#     write.csv2(df_url, fail, fileEncoding = "UTF-8", quote = "", na = NA_character_, row.names = FALSE)
-#     message(paste0("Some urls do not exists. Saved to: ", fail))
-#   }
-# })
-
 unlink(load_tmp_dir, recursive=TRUE)
\ No newline at end of file
